<?php
// $Id: entitlements.admin.inc,v 1.1.2.1 2010/09/20 03:28:15 erikwebb Exp $

/**
 * @file
 * Administrative forms and functions for the entitlements module.
 */

function entitlements() {
}

function entitlements_list() {
  require_once(drupal_get_path('module', 'entitlements') .'/entitlements.inc');

  $output = '';

  $avail_entitlements = array();

  $modules = module_implements('entitlements');
  if ($modules) {
    $avail_entitlements = array();
    foreach ($modules as $module) {
      $entitlement_list = module_invoke($module, 'entitlements', 'list');

      if (count($entitlement_list)) {
        $avail_entitlements = array_merge($avail_entitlements, $entitlement_list);
      }
    }

    $avail_entitlements = array_diff($avail_entitlements, _entitlements_load_all_eids());
  }

  foreach ($avail_entitlements as $key => $value) {
    if (user_access('edit entitlements') || user_access('administer entitlements')) {
      $avail_entitlements[$key] = $value . ' (' . l('create', 'admin/user/entitlements/add', array('query' => 'eid=' . $value)) . ')';
    }
  }

  $headers = array(
    array('data' => 'Entitlement', 'field' => 'eid'),
    array('data' => 'Entitlement name', 'field' => 'title'),
  );

  if (user_access('edit entitlements') || user_access('administer entitlements')) {
    $headers[] = array('data' => 'Actions');
  }


  $result = db_query('SELECT eid, title FROM {entitlements}' . tablesort_sql($headers));

  $rows = array();
  while ($row = db_fetch_array($result)) {
    if (user_access('edit entitlements') || user_access('administer entitlements')) {
      $row['eid'] = l($row['eid'], 'admin/user/entitlements/' . $row['eid']);
      $row['actions'] = l('Edit', 'admin/user/entitlements/' . $row['eid'] . '/edit');
      $row['actions'] .= ' ' . l('Delete', 'admin/user/entitlements/' . $row['eid'] . '/delete');
    }
    $rows[] = $row;
  }

  $output .= theme('table', $headers, $rows);

  if (count($avail_entitlements)) {
    $output .= '<h3>Available Entitlements</h3>';
    $output .= theme('item_list', $avail_entitlements);
  }

  return $output;
}

function entitlements_manage($args = array()) {
  $eid = arg(3);
  $action = arg(4);
}

function entitlements_edit() {

  return drupal_get_form('entitlements_edit_form');
}

function entitlements_edit_form() {
  require_once(drupal_get_path('module', 'entitlements') . '/entitlements.inc');

  $entitlement = new stdClass();

  if (arg(3) && arg(3) != 'add') {
    $entitlement = _entitlements_load(arg(3));
  }
  elseif (arg(3) == 'add') {
    if (array_key_exists('eid', $_GET))
      $entitlement->eid = $_GET['eid'];
  }

  $form = array();

  $form['eid'] = array(
    '#title' => 'Entitlement name',
    '#type' => 'textfield',
    '#required' => TRUE,
    '#value' => $entitlement->eid,
    '#attributes' => array('readonly' => 'readonly'),
  );

  $form['title'] = array(
    '#title' => 'Title',
    '#type' => 'textfield',
    '#required' => TRUE,
    '#maxsize' => 255,
    '#default_value' => $entitlement->title,
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Save',
  );

  $form['cancel'] = array(
    '#type' => 'submit',
    '#value' => 'Cancel',
  );

  if (arg(3) != 'add') {
    $form['eid']['#disabled'] = TRUE;
  }

  $form['#redirect'] = 'admin/user/entitlements';

  return $form;
}

function entitlements_edit_form_submit($form, &$form_state) {
  if ($form_state['clicked_button']['#value'] == 'Cancel') return;

  $entitlement = new stdClass();
  $entitlement->eid = $form_state['values']['eid'];
  $entitlement->title = $form_state['values']['title'];

  if (arg(3) && arg(3) != 'add') {
    $entitlement->eid = arg(3);
    $primary_keys = array('eid');
  }

  $result = drupal_write_record('entitlements', $entitlement, isset($primary_keys) ? $primary_keys : NULL);

  switch ($result) {
    case SAVED_NEW:
      drupal_set_message('New entitlement successfully created.');
      break;
    case SAVED_UPDATED:
      drupal_set_message('Entitlement successfully updated.');
      break;
    default:
      form_set_error('Unable to update entitlement.');
  }
}